@@ -450,9 +450,6 @@ exec_lookupevspec(struct exec *o, char *name, struct evspec *e) {
 		e->b1_min =  (e->b1_min << 7) & 0x3fff;
 		e->b1_max = ((e->b1_max << 7) & 0x3fff) | 0x7f;
 	}
-	dbg_puts("evspec: ");
-	evspec_dbg(e);
-	dbg_puts("\n");
 	return 1;
  toomany:
 	cons_err("too many ranges/values in event spec");
